"""
Package for the exception classes.
"""

from .euvdexception import EUVDException
from .euvdnotfoundexception import EUVDNotFoundException

__all__ = [
    "EUVDException",
    "EUVDNotFoundException",
]
